<template>
    <div class="app-container">
        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-form :model="objs" :rules="rules" ref="form" size="small" :inline="true" label-width="80px">
                    <el-form-item label="单位名称" prop="drugManufacturerId">
                        <el-select :remote-method="getRemoteData" v-model="objs.drugManufacturerId" remote filterable
                            style="width: 200px" placeholder="请选择单位名称" clearable @change="idFn">
                            <el-option v-for="dict in CompanyList" :key="dict.cnName" :label="dict.cnName"
                                :value="dict.drugManufacturerId" />
                        </el-select>
                    </el-form-item>
                    <el-form-item label="部门" prop="dwDeptName">
                        <el-select v-model="objs.dwDeptName" placeholder="请选择部门" style="width: 200px" clearable
                            @change="idBm">
                            <el-option v-for="dict in deptList" :key="dict.id" :label="dict.dwDeptName" :value="dict.id" />
                        </el-select>
                    </el-form-item>
                    <el-form-item label="分组" prop="payType">
                        <el-select v-model="objs.payType" placeholder="请选择结算方式" style="width: 200px" clearable>
                            <el-option v-for="dict in groupingList" :key="dict.id" :label="dict.groupingName"
                                :value="dict.id" />
                        </el-select>
                    </el-form-item>
                    <el-form-item label="登记时间" prop="createTimeList">
                        <el-date-picker v-model="createTimeList" type="datetimerange" align="right"
                            :picker-options="pickerOptions" style="width: 260px" start-placeholder="开始日期"
                            end-placeholder="结束日期" format="yyyy-MM-dd" value-format="yyyy-MM-dd"
                            @change="dateChangebirthday1">
                        </el-date-picker>
                    </el-form-item>
                </el-form>

            </el-col>
            <el-col :span="1.5">
                <el-button type="primary" size="mini" @click="handlequery"
                    v-hasPermi="['system:user:import']">查询</el-button>
            </el-col>

        </el-row>

        <div style="margin: 5px 20px;width: 94%">
            <el-row :gutter="10" class="mb8">
                <el-col :span="1.5">
                    <el-button type="primary" size="mini" :disabled="single" @click="handlesetup">添加全部基础项目</el-button>
                </el-col>
                <el-col :span="1.5">
                    <el-button type="primary" size="mini" :disabled="single" @click="handleAll">统计结果</el-button>
                </el-col>

            </el-row>
            <el-row :gutter="20">
                <!--部门数据-->
                <el-col :span="7" :xs="24">
                    <el-table v-loading="loading" ref="tree" :data="userList" border height="500"
                        @selection-change="handleSelectionChange">
                        <el-table-column type="selection" width="55">
                        </el-table-column>
                        <el-table-column label="体检号" align="center" prop="name"  />
                        <el-table-column label="姓名" align="center" prop="name" width="75" />
                        <el-table-column label="性别" align="center" prop="sex" width="75">
                            <template slot-scope="scope">
                                <dict-tag :options="dict.type.sys_user_sex" :value="scope.row.sex" />
                            </template>
                        </el-table-column>
                        <el-table-column label="年龄" align="center" prop="age" width="120" />
                    </el-table>
                </el-col>
                <el-col :span="8" :xs="24">
                    <el-table v-loading="loading" ref="tree" :data="userList" border height="500"
                        @selection-change="handleSelectionChange">
                        <el-table-column label="收费项目名称" align="center" prop="name" />
                    </el-table>
                </el-col>
                <el-col :span="8" :xs="24">
                    <el-table v-loading="loading" ref="tree" :data="userList" border height="500"
                        @selection-change="handleSelectionChange">
                        <el-table-column label="已选项目名称" align="center" prop="name"  />
                    </el-table>
                </el-col>
            </el-row>

        </div>


        <!-- 设置对话框 -->
        <div class="dia">
            <el-dialog :title="title1" :visible.sync="open1" width="960px" append-to-body>
                <div style="text-align: center;">
                    <el-transfer style="text-align: left; display: inline-block;" v-model="value" filterable
                        :left-default-checked="[2, 3]" :right-default-checked="[1]" :render-content="renderFunc"
                        :titles="['显示病种', '隐藏病种']" :button-texts="['显示', '隐藏']" :format="{
                            noChecked: '${total}',
                            hasChecked: '${checked}/${total}'
                        }" @change="handleChange1" :data="datalist">
                    </el-transfer>
                </div>
                <div slot="footer" class="dialog-footer2">
                    <el-button type="primary" @click="submitFormS">保存设置</el-button>
                </div>
            </el-dialog>
        </div>

    </div>
</template>
  
<script>
import { Deptlist, getDwAndDwDept } from "@/api/system/comp";
import { getCompany, queryCompany } from "@/api/team/tuanti";

export default {
    name: "Tijian",

    data() {
        let checkPhoneNum = (rule, value, callback) => {
         console.log( value)
      let patter = new RegExp(/^1\s*[3456789]\s*(\d\s*){9}$/);
      if (value == "" && value == undefined && !value) {
        return callback('');
      }  else if(value != undefined && value != ""){
        return callback();
      }else if (!patter.test(value)) {
        return callback('');
      }
    };
        const generateData = _ => {
            const data = [];
            for (let i = 1; i <= 15; i++) {
                data.push({
                    key: i,
                    label: `备选项 ${i}`,
                    disabled: i % 4 === 0
                });
            }
            return data;
        };
        return {
            datalist: generateData(),
            value: [1],
            value4: [1],
            renderFunc(h, option) {
                return <span>{option.key} - {option.label}</span>;
            },
            objs: {
                drugManufacturerId: "",
                dwDeptName: "",
                reservationTime: "",
            },
            data: {
                dwId: "",
                deptId: "",
            },
            // 弹出层标题
            title1: "",
            deptList: [],
            CompanyList: [],
            groupingList: [],
            userList: [],
            menuIds: [],
            proIds: [],
            open1: false,
            // 非单个禁用
            single: false,
            // 表单参数
            form: {},
            pickerOptions: {
                shortcuts: [
                    {
                        text: "最近一周",
                        onClick(picker) {
                            const end = new Date();
                            const start = new Date(new Date().setHours(0, 0, 0, 0));
                            start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
                            picker.$emit("pick", [start, end]);
                        },
                    },
                    {
                        text: "最近一个月",
                        onClick(picker) {
                            const end = new Date();
                            const start = new Date(new Date().setHours(0, 0, 0, 0));
                            start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
                            picker.$emit("pick", [start, end]);
                        },
                    },
                    {
                        text: "最近三个月",
                        onClick(picker) {
                            const end = new Date();
                            const start = new Date(new Date().setHours(0, 0, 0, 0));
                            start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
                            picker.$emit("pick", [start, end]);
                        },
                    },
                ],
            },
            // 表单校验
            rules: {
                drugManufacturerId: [
                    { required: true, validator: checkPhoneNum,  trigger: "change" },
                ],
                reservationTime: [
                    { required: true, validator: checkPhoneNum,  trigger: "blur" },
                ],
                dwDeptName: [
                    { required: true, validator: checkPhoneNum,  trigger: "change" },
                ],
            },
        };
    },
    created() {
        this.getNowTime()
        this.getList();
    },

    methods: {
        getList() {
            this.loading = true;
            getCompany(this.queryParam).then((response) => {
                this.CompanyList = response.data;
                this.total = response.total;
                this.loading = false;
            });
        },
        handlequery() {

        },
        handleQuery() {
            console.log(1111)
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            // this.ids = selection.map((item) => item.id);
            this.single = selection.length !== 1;
        },
        // 表单重置
        reset() {
            this.form = {
                company: null,
                payType: null,
                name: null,
                phoe: null,
                signingPic: null,
                pacStatus: "启用"
            };
            this.resetForm("form");
        },
        idFn(value) {
            this.data.dwId = value
            Deptlist(value).then((response) => {
                this.deptList = response.data;
            });
        },
        idBm(value) {
            this.data.deptId = value
            console.log(this.data)
            getDwAndDwDept(this.data).then((response) => {
                this.groupingList = response.data;
            });
        },

        // 搜索
        getRemoteData(query) {
            if (query) {
                let compName = query;
                queryCompany(compName).then((response) => {
                    this.CompanyList = response.data;
                    this.CompanyList.forEach((item) => {
                        this.objs = item;
                    });
                });
            }
        },
        // / 处理默认选中当前日期
        getNowTime() {
            var curDate = new Date().getTime();
            var dayNum = 7 * 24 * 3600 * 1000;
            var threeDays = curDate - dayNum;
            var sDay = this.getLocalTime(threeDays);
            var end = this.getLocalTime(curDate);
            this.createTimeList = [sDay, end];
        },
        add0(m) {
            return m < 10 ? "0" + m : m;
        },
        getLocalTime(nS) {
            var time = new Date(nS);
            var y = time.getFullYear();
            var m = time.getMonth() + 1;
            var d = time.getDate();
            // var h = time.getHours();
            // var mm = time.getMinutes();
            return (
                y +
                "-" +
                this.add0(m) +
                "-" +
                this.add0(d)
            );
        },
        //获取时间
        dateChangebirthday1(val) {
            if (val == null) {
                this.createTimeList = []
            } else {
                this.createTimeList = val;
            }
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        /** 查看详细信息按钮操作 */
        handleAll() {
            this.open = true;
            this.title = "团检检出率";
        },
        handleChange(selection) {
            // this.ids = selection.map((item) => item.id);
            this.single = selection.length !== 1;
        },
        handlecan() {

        },


        handlesetup() {
            this.open1 = true;
            this.title1 = "统计图设置";
        },
        handleChange1(value, direction, movedKeys) {
            console.log(value, direction, movedKeys);
        },
        submitFormS() {

        }
    },
};
</script>
  
<style>
.el-transfer-panel {
    width: 360px;
    height: 480px;
}

.el-transfer-panel__body {
    /* border: 1px solid red; */
    height: 480px;
}

.el-transfer-panel__list.is-filterable {
    height: 352px;
}

.el-button--primary.el-transfer__button {
    display: flex;
    justify-content: center;
    align-items: center;

}

.el-transfer__button:first-child {
    width: 82px;
    margin-bottom: 10px;
}

.el-button+.el-button {
    margin-left: 0px;
}
</style>